==> haskell-hxt-unicode-9.0.2.4-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-4EjbUlB6IEXJgiz1oBXiFr
key:                  hxt-unicode-9.0.2.4-4EjbUlB6IEXJgiz1oBXiFr
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  bd6823430ab0e117b2bc77ffb07e6586
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-8.10.1/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/hxt-unicode-9.0.2.4
hs-libraries:         HShxt-unicode-9.0.2.4-4EjbUlB6IEXJgiz1oBXiFr
depends:
    base-4.14.0.0 hxt-charproperties-9.4.0.0-8WBrTGDxJMv51F9pnJvmFg

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-unicode-9.0.2.4-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hxt-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-6A3G7dwxqUA9uYwzwU5zsR
key:                  hxt-unicode-9.0.2.4-6A3G7dwxqUA9uYwzwU5zsR
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  bb0b73d04b2abb8dffc30503d6f48064
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-8.10.2/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/hxt-unicode-9.0.2.4
hs-libraries:         HShxt-unicode-9.0.2.4-6A3G7dwxqUA9uYwzwU5zsR
depends:
    base-4.14.1.0 hxt-charproperties-9.4.0.0-BqlLtdXD5t9DWp3nNayMl

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
